Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::op_dv_vari Member List

This is the complete list of members for stan::math::op_dv_vari, including all inherited members.

ad_ | stan::math::op_dv_vari | protected
adj_ | stan::math::vari |
bvi_ | stan::math::op_dv_vari | protected
chain() | stan::math::vari | inlinevirtual
init_dependent() | stan::math::vari | inline
op_dv_vari(double f, double a, vari *bvi) | stan::math::op_dv_vari | inline
operator delete(void *) | stan::math::vari | inlinestatic
operator new(size_t nbytes) | stan::math::vari | inlinestatic
set_zero_adjoint() | stan::math::vari | inline
val_ | stan::math::vari |
vari(const double x) | stan::math::vari | inlineexplicit
vari(const double x, bool stacked) | stan::math::vari | inline
~vari() | stan::math::vari | inlinevirtual

[ Stan Home Page ] © 2011–2016, Stan Development Team.